@@ -1,17 +1,33 @@
 /*
-	$Id: inputsource_memory_generic.cpp,v 1.11 2001/12/11 20:44:21 mbn Exp $
-
-	------------------------------------------------------------------------
-	ClanLib, the platform independent game SDK.
-
-	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
-	version 2. See COPYING for details.
-
-	For a total list of contributers see CREDITS.
-
-	------------------------------------------------------------------------
+**  ClanLib SDK
+**  Copyright (c) 1997-2005 The ClanLib Team
+**
+**  This software is provided 'as-is', without any express or implied
+**  warranty.  In no event will the authors be held liable for any damages
+**  arising from the use of this software.
+**
+**  Permission is granted to anyone to use this software for any purpose,
+**  including commercial applications, and to alter it and redistribute it
+**  freely, subject to the following restrictions:
+**
+**  1. The origin of this software must not be misrepresented; you must not
+**     claim that you wrote the original software. If you use this software
+**     in a product, an acknowledgment in the product documentation would be
+**     appreciated but is not required.
+**  2. Altered source versions must be plainly marked as such, and must not be
+**     misrepresented as being the original software.
+**  3. This notice may not be removed or altered from any source distribution.
+**
+**  Note: Some of the libraries ClanLib may link to may have additional
+**  requirements or restrictions.
+**
+**  File Author(s):
+**
+**    Magnus Norddahl
+**    (if your name is missing here, please add it)
 */
 
+#include <cstring>
 #include "Core/precomp.h"
 
 #include "API/Core/System/cl_assert.h"
@@ -113,7 +129,7 @@ void CL_InputSource_MemoryGeneric::pop_position()
 
 void CL_InputSource_MemoryGeneric::purge()
 {
-	memcpy(data, 0, length);
+	memset(data, 0, length);
 }
 
 CL_InputSourceProvider_Memory::CL_InputSourceProvider_Memory(unsigned char *_data, unsigned int _size, bool _delete_data)
