@@ -1,15 +1,36 @@
-/***************************************************************************
- *
- * DetectMMX.cpp
- * by Darryl Agostinelli March 4, 2000
- *
- * Code was adopted from Intel web page
- *
- */
+/*
+**  ClanLib SDK
+**  Copyright (c) 1997-2005 The ClanLib Team
+**
+**  This software is provided 'as-is', without any express or implied
+**  warranty.  In no event will the authors be held liable for any damages
+**  arising from the use of this software.
+**
+**  Permission is granted to anyone to use this software for any purpose,
+**  including commercial applications, and to alter it and redistribute it
+**  freely, subject to the following restrictions:
+**
+**  1. The origin of this software must not be misrepresented; you must not
+**     claim that you wrote the original software. If you use this software
+**     in a product, an acknowledgment in the product documentation would be
+**     appreciated but is not required.
+**  2. Altered source versions must be plainly marked as such, and must not be
+**     misrepresented as being the original software.
+**  3. This notice may not be removed or altered from any source distribution.
+**
+**  Note: Some of the libraries ClanLib may link to may have additional
+**  requirements or restrictions.
+**
+**  File Author(s):
+**
+**    Darryl Agostinelli March 4, 2000
+**    Code was adopted from Intel web page
+*/
 
 #include "Core/precomp.h"
 #include "API/Core/System/system.h"
 #include "API/Core/System/cl_assert.h"
+#include "API/Core/System/log.h"
 
 static bool do_mmx_test();
 
@@ -41,11 +62,11 @@ static bool do_mmx_test()
 								//	0 = vendor string, 1 = version info, 2 = cache info
 			CPUID				// code bytes = 0fh,  0a2h
 			mov RegEDX, edx		// features returned in edx
-	   	}
-   	}
+		}
+	}
 	catch(...)					// catch everything
 	{
-		return false;        	// processor does not support CPUID
+		return false;			// processor does not support CPUID
 	}
 
 	if (RegEDX & 0x800000) 		// bit 23 is set for MMX technology
@@ -53,8 +74,8 @@ static bool do_mmx_test()
 		try { _asm {emms} }		// try executing the MMX instruction "emms"
 		catch(...) { return false; }
 	}
-   	else
-		return false;        	// processor supports CPUID but does not support MMX technology
+	else
+		return false;			// processor supports CPUID but does not support MMX technology
 
 	// if we get here, it means the processor has MMX technology but
 	// floating-point emulation is on; so MMX technology is unavailable
@@ -93,35 +114,33 @@ static bool do_mmx_test()
 	#ifdef USE_TASM
 	int RegEDX=0;
 	try
-  {
-  	asm
-    {
-    	mov eax, 1
-      CPUID
-      mov RegEDX, edx
-    }
-  }
-  catch(...) {return false;}
+	{
+	asm
+	{
+		mov eax, 1
+		CPUID
+		mov RegEDX, edx
+	}
+	}
+	catch(...) {return false;}
 
-  if (RegEDX & 0x800000)
-  {
-  	try{asm{emms}}
+	if (RegEDX & 0x800000)
+	{
+		try{asm{emms}}
 		catch(...) {return false;}
-  }
-  else
-  	return false;
-  return true;
+	}
+	else
+		return false;
+	return true;
 #else
 
-	std::cout<<"Support to detect this has not been compiled in.  Please check source(detect_mmx.cpp)"<<std::endl;
-  return false;
+	CL_Log::log("debug", "Support to detect this has not been compiled in.");
+	return false;
 #endif //Endif USE_TASM
 
 #else
-
-	cl_info(0, "CL_System::detect_mmx() not implemented under your OS/Compiler/Architecture.");
+	// Not implemented
 	return false;
-
 #endif
 
 #else
