@@ -1,17 +1,36 @@
 /*
-	$Id: mutex_pthread.cpp,v 1.5 2002/06/22 12:58:04 mbn Exp $
-
-	------------------------------------------------------------------------
-	ClanLib, the platform independent game SDK.
-
-	This library is distributed under the GNU LIBRARY GENERAL PUBLIC LICENSE
-	version 2. See COPYING for details.
-
-	For a total list of contributers see CREDITS.
-
-	------------------------------------------------------------------------
+**  ClanLib SDK
+**  Copyright (c) 1997-2005 The ClanLib Team
+**
+**  This software is provided 'as-is', without any express or implied
+**  warranty.  In no event will the authors be held liable for any damages
+**  arising from the use of this software.
+**
+**  Permission is granted to anyone to use this software for any purpose,
+**  including commercial applications, and to alter it and redistribute it
+**  freely, subject to the following restrictions:
+**
+**  1. The origin of this software must not be misrepresented; you must not
+**     claim that you wrote the original software. If you use this software
+**     in a product, an acknowledgment in the product documentation would be
+**     appreciated but is not required.
+**  2. Altered source versions must be plainly marked as such, and must not be
+**     misrepresented as being the original software.
+**  3. This notice may not be removed or altered from any source distribution.
+**
+**  Note: Some of the libraries ClanLib may link to may have additional
+**  requirements or restrictions.
+**
+**  File Author(s):
+**
+**    Magnus Norddahl
+**    (if your name is missing here, please add it)
 */
 
+#ifndef __USE_UNIX98
+	#define __USE_UNIX98
+#endif  
+
 #include "Core/precomp.h"
 #include "API/Core/System/cl_assert.h"
 #include <pthread.h>
@@ -21,7 +40,11 @@
 // suck:
 extern "C"
 {
+#ifdef __FreeBSD__
+	int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int kind);
+#else
 	int pthread_mutexattr_setkind_np(pthread_mutexattr_t *attr, int kind);
+#endif
 }
 
 CL_Mutex *CL_Mutex::create()
@@ -36,10 +59,20 @@ CL_Mutex::CL_Mutex()
 {
 	pthread_mutexattr_t attr;
 	pthread_mutexattr_init(&attr);
-#ifndef linux
+
+#ifdef __APPLE__
+	pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE );
+#else
+#ifdef __FreeBSD__
+        pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+#else
+#if PTHREAD_MUTEX_RECURSIVE_NP
+// cygwin
 	pthread_mutexattr_setkind_np(&attr, PTHREAD_MUTEX_RECURSIVE);
 #else
 	pthread_mutexattr_setkind_np(&attr, PTHREAD_MUTEX_RECURSIVE_NP);
+#endif
+#endif
 #endif
 	pthread_mutex_init(&impl->mutex, &attr);
 	pthread_mutexattr_destroy(&attr);
