@@ -1,17 +1,37 @@
 /*
-	$Id: inputbox.cpp,v 1.45 2002/03/01 22:19:09 sphair Exp $
-	
-	ClanGUI, copyrights by various people. Have a look in the CREDITS file.
-	
-	This sourcecode is distributed using the Library GNU Public Licence,
-	version 2 or (at your option) any later version. Please read LICENSE
-	for details.
+**  ClanLib SDK
+**  Copyright (c) 1997-2005 The ClanLib Team
+**
+**  This software is provided 'as-is', without any express or implied
+**  warranty.  In no event will the authors be held liable for any damages
+**  arising from the use of this software.
+**
+**  Permission is granted to anyone to use this software for any purpose,
+**  including commercial applications, and to alter it and redistribute it
+**  freely, subject to the following restrictions:
+**
+**  1. The origin of this software must not be misrepresented; you must not
+**     claim that you wrote the original software. If you use this software
+**     in a product, an acknowledgment in the product documentation would be
+**     appreciated but is not required.
+**  2. Altered source versions must be plainly marked as such, and must not be
+**     misrepresented as being the original software.
+**  3. This notice may not be removed or altered from any source distribution.
+**
+**  Note: Some of the libraries ClanLib may link to may have additional
+**  requirements or restrictions.
+**
+**  File Author(s):
+**
+**    Magnus Norddahl
+**    (if your name is missing here, please add it)
 */
 
 #include "precomp.h"
+#include "API/Core/XML/dom_element.h"
 #include "API/GUI/inputbox.h"
-#include "API/GUI/component_options.h"
 #include "API/GUI/stylemanager.h"
+#include "API/Core/System/clanstring.h"
 #include "inputbox_generic.h"
 
 /////////////////////////////////////////////////////////////////////////////
@@ -22,7 +42,7 @@ CL_InputBox::CL_InputBox(
 	CL_StyleManager *style)
 : CL_Component(parent, style), impl(NULL)
 {
-	impl = new CL_InputBox_Generic(this, std::string(), false, false, 1024);
+	impl = new CL_InputBox_Generic(this, std::string(), false, false, 0);
 	get_style_manager()->connect_styles("inputbox", this);
 	find_preferred_size();
 }
@@ -77,7 +97,7 @@ const std::string &CL_InputBox::get_text() const
 	return impl->text;
 }
 
-const std::string &CL_InputBox::get_marked_text() const
+std::string CL_InputBox::get_marked_text() const
 {
 	return impl->get_marked_text();
 }
@@ -122,6 +142,36 @@ bool CL_InputBox::is_edited() const
 	return impl->edited;
 }
 
+/////////////////////////////////////////////////////////////////////////////
+// Added by AlexeyKharkov:
+
+void CL_InputBox::on_input_down(const CL_InputEvent &key)
+{
+	impl->on_input_down(key);
+}
+void CL_InputBox::on_input_up(const CL_InputEvent &key)
+{
+	impl->on_input_up(key);
+}
+
+void CL_InputBox::on_mouse_Ldown( int mouse_pos )
+{
+	impl->on_mouse_Ldown( mouse_pos );
+}
+void CL_InputBox::on_mouse_Lup( int mouse_pos )
+{
+	impl->on_mouse_Lup( mouse_pos );
+}
+void CL_InputBox::on_mouse_move( int mouse_pos )
+{
+	impl->on_mouse_move( mouse_pos );
+}
+
+void CL_InputBox::on_lost_focus()
+{
+	impl->on_lost_focus();
+}
+
 /////////////////////////////////////////////////////////////////////////////
 // Operations:
 
@@ -132,16 +182,12 @@ void CL_InputBox::set_text(const std::string &text)
 
 void CL_InputBox::set_text(int number)
 {
-	char buf[20];
-	sprintf(buf, "%d", number);
-	impl->set_text(buf);
+	impl->set_text(CL_String::format("%1", number));
 }
 
 void CL_InputBox::set_text(double number)
 {
-	char buf[20];
-	sprintf(buf, "%f", number);
-	impl->set_text(buf);
+	impl->set_text(CL_String::format("%1", number));
 }
 
 void CL_InputBox::set_max_length(int length)
@@ -241,3 +287,8 @@ CL_Signal_v0 &CL_InputBox::sig_activity()
 {
 	return impl->sig_activity;
 }
+
+CL_Signal_v2<char &, bool &> &CL_InputBox::sig_validate_character()
+{
+	return impl->sig_validate_character;
+}
